# Python Connector for HubSpot #

Python Connector for HubSpot is a connectivity solution for accessing HubSpot
from Python applications to read and update data. It fully implements
the Python DB API 2.0 specification. The connector is distributed as a wheel
package for Windows and Windows Server.
 
Standard SQL syntax
 
The connector fully supports the ANSI SQL standard and lets you execute
SQL statements against your HubSpot data just like you would normally work
with relational databases. Simple queries are directly converted
to HubSpot API calls and executed on the HubSpot side.

## Using the connector ##

To retrieve data from a database:
 
Import the module.
 
```
import devart.hubspot
```
 
Connect to a database using the `connect()` module method and obtain a `connection` object:
 
If you authenticate using an API key: 
```
my_connection = devart.hubspot.connect(
    Authentication="APIKey",
    APIKey="your_api_key"
)
```
If you authenticate using an access token: 
```
my_connection = devart.hubspot.connect(
    Authentication="PrivateApp",
    AccessToken="your_access_token"
)
```
If you're using OAuth 2.0 authentication and have a refresh token:
```
my_connection = devart.hubspot.connect(
    Authentication="OAuth",
    RefreshToken="your_refresh_token"
)
```
If you're using OAuth 2.0 authentication and don't have a refresh token:
```
dict = hubspot.signin()
my_connection = devart.hubspot.connect(
    Authentication="OAuth",
    RefreshToken=dict["Refresh Token"]
)
```
 
Create a `cursor` object using the `cursor()` connection method.
 
```
my_cursor = my_connection.cursor()
```
 
Execute the SQL statement using the `execute()` cursor method.
 
```
my_cursor.execute("SELECT * FROM employees")
```
 
Retrieve the result set using one of the `fetch*()` cursor methods.
 
```
for row in my_cursor.fetchall(): 
    print(row)
```

## What's new ##

Python Connector for HubSpot 1.0
 
* Initial release of Python Connector for HubSpot
* Added support for Windows 32-bit and 64-bit
* Added support for Windows Server 32-bit and 64-bit
